@@ -22,15 +22,17 @@ pub const SPINNER_FRAMES: &[&str] = &[
     "⠀⢘", "⠀⡘", "⠀⠨", "⠀⢐", "⠀⡐", "⠀⠠", "⠀⢀", "⠀⡀", "  ", "  ",
 ];
 pub const SPINNER_RATE: u64 = 48;
-pub const INSTALLED_DOTFILES_MANIFEST_PATH: &str = "~/.local/share/jointhedots/manifest.yaml";
 
 pub fn run_command_vec(command_vec: &[String]) -> Result<(), Box<dyn Error>> {
     for (stage, command) in command_vec.iter().enumerate() {
         println!("{} {}", style(format!("Step #{}:", stage)).cyan(), command);
         io::stdout().flush()?;
 
-        let command_vec: Vec<&str> = command.split(' ').collect();
-        Command::new(command_vec[0])
+        let command_vec: Vec<String> = command
+            .split(' ')
+            .map(|component| shellexpand::tilde(component).to_string())
+            .collect();
+        Command::new(command_vec[0].as_str())
             .args(&command_vec[1..])
             .spawn()?
             .wait_with_output()?;
@@ -38,14 +40,17 @@ pub fn run_command_vec(command_vec: &[String]) -> Result<(), Box<dyn Error>> {
     Ok(())
 }
 
-pub fn get_manifest(target_dir: &Path) -> Result<Manifest, Box<dyn Error>> {
-    let mut path = target_dir.to_owned();
-    path.push("jtd.yaml");
-
-    let config: Manifest = serde_yaml::from_reader(
-        File::open(path).map_err(|_| "Could not find manifest in repository.")?,
-    )
-    .map_err(|_| "Could not parse manifest.")?;
+pub fn get_manifest(manifest_path: &Path) -> Result<Manifest, Box<dyn Error>> {
+    let config: Manifest = serde_yaml::from_reader(File::open(manifest_path).map_err(|_| {
+        format!(
+            "Could not find manifest {} in repository.",
+            manifest_path
+                .file_name()
+                .map(|v| v.to_string_lossy())
+                .unwrap_or_else(|| "N/A".into())
+        )
+    })?)
+    .map_err(|err| format!("Could not parse manifest: {}", err))?;
     Ok(config)
 }
 
@@ -68,6 +73,14 @@ pub(crate) fn hash_command_vec(command_vec: &[String]) -> String {
 mod tests {
     use super::*;
 
+    #[test]
+    fn test_run_command_vec() {
+        let path = Path::new("/tmp/test-jtd");
+        let command_vec = vec![format!("touch {}", path.to_string_lossy())];
+        run_command_vec(&command_vec).expect("Could not run command vec");
+        assert!(Path::new("/tmp/test-jtd").exists());
+    }
+
     #[test]
     fn test_hash_command_vec() {
         let command_vec = vec![
